Module pollable

Module pollable 

Traits that make the Selector generic over asynchronous tasks and polling logic.

Unless you want to exercise the full flexibility of the selector, you don’t need to use these traits. You can use plain FutureSelector and StreamSelector.

Structs

PollDirect
Noop PollProxy that only works with Pollables.
PollFuture
PollProxy that transforms Futures into Pollable tasks.
PollStream
PollProxy that transforms Streams into Pollable tasks.

Traits

PollProxy
Sealed complementary trait used internally by Selector.
Pollable
Task that can be polled inside a Selector.