PollStrategy

Trait PollStrategy 

pub trait PollStrategy {
    type Pollable;
}
Determines the type of pollable task that can be stored in a Selector.

This trait exists solely to enable non-conflicting blanket implementations for Futures and Streams.

Required Associated Types

type Pollable

Type of the task that will be stored in the Selector.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors