Module selector
async_
selector
0.2.0
Module selector
Module Items
Modules
Structs
In crate async_
selector
async_selector
Module
selector
Fast and flexible
Future
/
Stream
selector.
Modules

ext
Wrapper types for
Selector
that allow for customizing polling behavior.
iter
Types for iterating over tasks stored in a
Selector
.
Structs

Borrowed
An immutable borrow of a task stored in a
Selector
.
Borrowed
Mut
Mutable borrow of a task stored in a
Selector
.
Id
A unique id of a task stored in a
Selector
.
Removed
Task removed from a
Selector
.
Selector
Selector over a dynamic set of pollable tasks, for example
Future
s and
Stream
s.