Module ext

Module ext 

Wrapper types for Selector that allow for customizing polling behavior.

Structs

WithExt
Borrowed Stream that will poll the inner Selector and pass the extensions to the inner tasks.
WithExtAndId
Borrowed Stream that will poll the inner Selector, pass the extensions the inner tasks, and attach the origin task Id to every item.
WithId
Borrowed Stream that will poll the inner Selector and attach the origin task Id to every item.