Module iter

Module iter 

Types for iterating over tasks stored in a Selector.

Structs

ExtractIf
Iterator which uses a closure to determine if a task should be removed from a Selector.
IntoIter
Iterator that returns tasks stored previously in a Selector.
Iter
Iterator that visits tasks stored in a Selector.
IterMut
Iterator that allows for modifying tasks stored in a Selector.