Borrowed

Struct Borrowed 

pub struct Borrowed<'a, T>(/* private fields */);
Immutable reference to a task stored in a Selector.

Implementations

Source

impl<'a, T> Borrowed<'a, T>

pub fn id(&self) -> &Id<T>

Returns the ID of the task.

pub fn get_pin(&self) -> Pin<&T>

Returns a pinned reference to the task.

pub fn into_pin(self) -> Pin<&'a T>

Consumes this wrapper, returning a pinned reference to the task.