BorrowedMut

Struct BorrowedMut 

pub struct BorrowedMut<'a, P> { /* private fields */ }
Mutable borrow of a task stored in a Selector.

Important: before modifying tasks stored in the selector, see the wakeups section.

Implementations

Source

impl<P> BorrowedMut<'_, P>

pub fn wake(&self)

Manually wakes the task.

pub fn id(&self) -> Id<P>

Returns the id of this task.

pub fn get_mut(&mut self) -> Pin<&mut P>

Returns a pinned reference to the task.

Important: before modifying tasks stored in the selector, see the wakeups section.