Id

Struct Id 

pub struct Id<C>(/* private fields */);
Unique ID of a task pushed into a Selector.

This ID is always unique relative to all other IDs, including IDs obtained from other selectors.

Implementations

Source

impl<C> Id<C>

pub fn wake(&self)

Manually wakes this task.

Does nothing if the task is no longer stored in the selector.