Selector

Struct Selector 

pub struct Selector<T, S> { /* private fields */ }
Selector over a dynamic set of Tasks (generalized Futures/Streams).

Inspired by FuturesUnordered, designed for flexibility and optimal performance when polling a large number of tasks.

Unless you want to exercise the full flexibility of this type, you can stick to the specializations exposed in the root of this crate (e.g. FutureSelector and StreamSelector).

Removal

The selector creates a heap allocation for each stored task. Removing a task from the selector does not instantly free that memory. The memory can only be freed when:

  1. all Id instances for this task are dropped, AND
  2. Removed instance is dropped, AND
  3. the Waker (and all its clones) passed when polling the task is dropped, AND
  4. the selector observes the task removal (which happens when the selector is polled).

Wakeups

The selector uses a smart strategy for polling the tasks. A task is only polled in the following cases:

  1. after it is pushed into the selector
  2. after it yields a non-terminal value
  3. after the waker passed to Task::poll_progress receives a wakeup

To avoid nasty surprises, keep this in mind when:

  1. Modifying a task borrowed from the selector
  2. Changing the strategy used by the selector (see example)

The wakeups are stored in a FIFO queue. This implies that the selector processes ready tasks in a round-robin fashion.

Panic

If the Task implementation panics, the task is removed from the selector and dropped, and the panic propagates. The selector remains valid.

Implementations

Source

impl<T, S> Selector<T, S>

pub fn new(strategy: S) -> Self

Creates an empty selector with the given strategy.

pub fn push(&mut self, task: T) -> BorrowedMut<'_, T>

Pushes the given task into the selector, returning a mutable reference to the task.

The reference can be used to obtain the task’s Id.

This method is O(1).

pub fn len(&self) -> usize

Returns the number of tasks stored in the selector.

This method is O(1).

pub fn is_empty(&self) -> bool

Returns whether the selector is empty.

This method is O(1).

pub fn contains(&self, id: &Id<T>) -> bool

Returns whether the selector contains a task with the given Id.

This method is O(1).

pub fn get<'a>(&'a self, id: &Id<T>) -> Option<Borrowed<'a, T>>

If the selector contains a task with the given Id, returns a reference to it.

This method is O(1).

pub fn get_mut<'a>(&'a mut self, id: &Id<T>) -> Option<BorrowedMut<'a, T>>

If the selector contains a task with the given Id, returns a mutable reference to it.

This method is O(1).

pub fn remove(&mut self, id: &Id<T>) -> Option<Removed<T>>

If the selector contains a task with the given Id, removes it.

This method is O(1).

pub fn strategy(&self) -> &S

Returns a reference to the strategy used by this selector.

pub fn strategy_mut(&mut self) -> &mut S

Returns a mutable reference to the strategy used by this selector.

pub fn with_strategy<S1>(self, strategy: S1) -> Selector<T, S1>

Returns a new selector with the same state, but different strategy.

pub fn iter(&self) -> Iter<'_, T>

Returns an iterator over all tasks in the selector.

The tasks are visited in the insertion order.

pub fn iter_mut(&mut self) -> IterMut<'_, T>

Returns an iterator that allows for modifying each task in the selector.

The tasks are visited in the insertion order.

pub fn extract_if<F>(&mut self, pred: F) -> ExtractIf<'_, T, F>
where F: for<'b> FnMut(BorrowedMut<'b, T>) -> bool,

Creates an iterator which uses a closure to determine if a task should be removed.

If the closure returns true, the task is removed from the selector and yielded. The tasks are visited in the insertion order.

If the returned ExtractIf is not exhausted, e.g. because it is dropped without iterating or the iteration short-circuits, then the remaining tasks will be retained.

pub fn retain<F>(&mut self, pred: F)
where F: for<'b> FnMut(BorrowedMut<'b, T>) -> bool,

Retains only the tasks specified by the predicate.

In other words, remove all tasks for which the predicate returns false. The tasks are visited in the insertion order.

pub fn wake_all(&self)

Manually wakes all tasks in the selector.