Module task

Module task 

Modules

strategy
Set of strategies that provide blanket Task implementations for implementors of common traits: Future, Stream and TryStream.

Traits

Task
Asynchronous task that can be polled with strategy S.