pub struct FutureBasic;Expand description
Yield future’s output.
Enables Task implementation on any type that implements Future.
The future will be polled until it resolves.
After that, the Selector will
silently drop it and yield the output.
let mut selector = (0..4)
.map(std::future::ready)
.collect::<Selector<_, FutureBasic>>();
for i in 0..4 {
let j: i32 = selector.next().await.unwrap();
assert_eq!(j, i);
}
assert!(selector.is_empty());Trait Implementations
Sourceimpl Clone for FutureBasic
impl Clone for FutureBasic
Sourcefn clone(&self) -> FutureBasic
fn clone(&self) -> FutureBasic
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FutureBasic
Sourceimpl Debug for FutureBasic
impl Debug for FutureBasic
Sourceimpl Default for FutureBasic
impl Default for FutureBasic
Sourcefn default() -> FutureBasic
fn default() -> FutureBasic
Returns the “default value” for a type. Read more
Sourceimpl<F: Future> Task<FutureBasic> for F
impl<F: Future> Task<FutureBasic> for F
Sourcetype Cont = Infallible
type Cont = Infallible
Type returned from
Self::poll_progress
when the task produces some value, but has not finished yet.Sourcetype Break = <F as Future>::Output
type Break = <F as Future>::Output
Type returned from
Self::poll_progress
when the task produces its last value.Sourcetype Output = <F as Future>::Output
type Output = <F as Future>::Output
Final value type, produced from
Self::Cont/Self::Break
in Self::transform_cont/Self::transform_break.Sourcefn poll_progress(
self: Pin<&mut Self>,
_: &mut FutureBasic,
cx: &mut Context<'_>,
) -> Poll<ControlFlow<Self::Break, Self::Cont>>
fn poll_progress( self: Pin<&mut Self>, _: &mut FutureBasic, cx: &mut Context<'_>, ) -> Poll<ControlFlow<Self::Break, Self::Cont>>
Polls progress on this task using the given strategy. Read more
Sourcefn transform_cont(
_: BorrowedMut<'_, Self>,
_: &mut FutureBasic,
_: Self::Cont,
) -> Option<Self::Output>
fn transform_cont( _: BorrowedMut<'_, Self>, _: &mut FutureBasic, _: Self::Cont, ) -> Option<Self::Output>
Transforms
Self::Cont value obtained from Self::poll_progress
into the final value type Self::Output. Read moreSourcefn transform_break(
_: Removed<F>,
_: &mut FutureBasic,
value: Self::Break,
) -> Option<Self::Output>
fn transform_break( _: Removed<F>, _: &mut FutureBasic, value: Self::Break, ) -> Option<Self::Output>
Transforms
Self::Break value obtained from Self::poll_progress
into the final value type Self::Output. Read moreAuto Trait Implementations
impl Freeze for FutureBasic
impl RefUnwindSafe for FutureBasic
impl Send for FutureBasic
impl Sync for FutureBasic
impl Unpin for FutureBasic
impl UnsafeUnpin for FutureBasic
impl UnwindSafe for FutureBasic