pub struct FutureReclaim;Expand description
Yield future’s output and the future itself.
Enables Task implementation on any type that implements Future.
The future will be polled until it resolves.
After that, the Selector will
yield the output and the future itself.
let mut selector = (0..4)
.map(futures::future::ready)
.collect::<Selector<_, FutureReclaim>>();
for i in 0..4 {
let item: (Removed<Ready<i32>>, i32) = selector.next().await.unwrap();
assert!(item.0.is_terminated());
assert_eq!(item.1, i);
}
assert!(selector.is_empty());Trait Implementations
Sourceimpl Clone for FutureReclaim
impl Clone for FutureReclaim
Sourcefn clone(&self) -> FutureReclaim
fn clone(&self) -> FutureReclaim
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FutureReclaim
Sourceimpl Debug for FutureReclaim
impl Debug for FutureReclaim
Sourceimpl Default for FutureReclaim
impl Default for FutureReclaim
Sourcefn default() -> FutureReclaim
fn default() -> FutureReclaim
Returns the “default value” for a type. Read more
Sourceimpl<F: Future> Task<FutureReclaim> for F
impl<F: Future> Task<FutureReclaim> for F
Sourcetype Cont = Infallible
type Cont = Infallible
Type returned from
Self::poll_progress
when the task produces some value, but has not finished yet.Sourcetype Break = <F as Future>::Output
type Break = <F as Future>::Output
Type returned from
Self::poll_progress
when the task produces its last value.Sourcetype Output = (Removed<F>, <F as Future>::Output)
type Output = (Removed<F>, <F as Future>::Output)
Final value type, produced from
Self::Cont/Self::Break
in Self::transform_cont/Self::transform_break.Sourcefn poll_progress(
self: Pin<&mut Self>,
_: &mut FutureReclaim,
cx: &mut Context<'_>,
) -> Poll<ControlFlow<Self::Break, Self::Cont>>
fn poll_progress( self: Pin<&mut Self>, _: &mut FutureReclaim, cx: &mut Context<'_>, ) -> Poll<ControlFlow<Self::Break, Self::Cont>>
Polls progress on this task using the given strategy. Read more
Sourcefn transform_cont(
_: BorrowedMut<'_, F>,
_: &mut FutureReclaim,
_: Self::Cont,
) -> Option<Self::Output>
fn transform_cont( _: BorrowedMut<'_, F>, _: &mut FutureReclaim, _: Self::Cont, ) -> Option<Self::Output>
Transforms
Self::Cont value obtained from Self::poll_progress
into the final value type Self::Output. Read moreSourcefn transform_break(
task: Removed<F>,
_: &mut FutureReclaim,
value: Self::Break,
) -> Option<Self::Output>
fn transform_break( task: Removed<F>, _: &mut FutureReclaim, value: Self::Break, ) -> Option<Self::Output>
Transforms
Self::Break value obtained from Self::poll_progress
into the final value type Self::Output. Read moreAuto Trait Implementations
impl Freeze for FutureReclaim
impl RefUnwindSafe for FutureReclaim
impl Send for FutureReclaim
impl Sync for FutureReclaim
impl Unpin for FutureReclaim
impl UnsafeUnpin for FutureReclaim
impl UnwindSafe for FutureReclaim