StreamBasic

Struct StreamBasic 

pub struct StreamBasic;
Yield stream’s items.

Enables Task implementation on any type that implements Stream.

The stream will be polled for items until it is exhausted. Selector will yield all items. After that, the Selector will silently drop the stream.

let mut selector = (0..4)
    .map(|i| futures::stream::repeat(i).take(2))
    .collect::<Selector<_, StreamBasic>>();
for i in 0..8 {
    let j: i32 = selector.next().await.unwrap();
    assert_eq!(j, i % 4);
}
assert!(selector.next().await.is_none());
assert!(selector.is_empty());