StreamReclaim

Struct StreamReclaim 

pub struct StreamReclaim;
Yield stream’s items annotated with stream Id, and the exhausted stream itself.

Enables Task implementation on any type that implements Stream.

The stream will be polled for items until it is exhausted. Selector will yield all items, attaching stream’s task Id to each. After that, the Selector will yield the exhausted stream.

let (tx, rx) = mpsc::unbounded::<i32>();
let mut selector = Selector::<_, StreamReclaim>::default();
let id = selector.push(rx).id().clone();
tx.unbounded_send(1).unwrap();
match selector.next().await.unwrap() {
    ControlFlow::Continue(item) => {
        assert_eq!(item.0, id);
        assert_eq!(item.1, 1);       
    }
    ControlFlow::Break(..) => unreachable!("channel is still open"),
}
drop(tx);
match selector.next().await.unwrap() {
    ControlFlow::Continue(..) => {
        unreachable!("channel was closed");
    }
    ControlFlow::Break((item)) => {
        let rx: mpsc::UnboundedReceiver<i32> = item.into_inner();
    }
}
assert!(selector.is_empty());