pub struct StreamWithId;Expand description
Yield stream’s items annotated with stream Id.
Enables Task implementation on any type that implements Stream.
The stream will be polled for items until it is exhausted.
Selector will yield all items, attaching stream’s task Id to each.
After that, the Selector will silently drop the stream.
let (tx, rx) = mpsc::unbounded::<i32>();
let mut selector = Selector::<_, StreamWithId>::default();
let id = selector.push(rx).id().clone();
tx.unbounded_send(1).unwrap();
let item: (Id<_>, i32) = selector.next().await.unwrap();
assert_eq!(item.0, id);
assert_eq!(item.1, 1);
drop(tx);
assert!(selector.next().await.is_none());
assert!(selector.is_empty());Trait Implementations
Sourceimpl Clone for StreamWithId
impl Clone for StreamWithId
Sourcefn clone(&self) -> StreamWithId
fn clone(&self) -> StreamWithId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StreamWithId
Sourceimpl Debug for StreamWithId
impl Debug for StreamWithId
Sourceimpl Default for StreamWithId
impl Default for StreamWithId
Sourcefn default() -> StreamWithId
fn default() -> StreamWithId
Returns the “default value” for a type. Read more