pub struct TryStreamBasic;Expand description
Yield stream’s items (stopping after first error).
Enables Task implementation on any type that implements TryStream.
The stream will be polled for items until it is exhausted or yields an error.
Selector will yield all items and the first error.
After that, the Selector will silently drop the stream.
let (tx_1, rx_1) = mpsc::unbounded::<Result<i32, &'static str>>();
let (tx_2, rx_2) = mpsc::unbounded::<Result<i32, &'static str>>();
let mut selector = [rx_1, rx_2].into_iter().collect::<Selector::<_, TryStreamBasic>>();
tx_1.unbounded_send(Err("error")).unwrap();
assert_eq!(
selector.next().await.unwrap(),
Err("error"),
);
tx_2.unbounded_send(Ok(1)).unwrap();
assert_eq!(
selector.next().await.unwrap(),
Ok(1),
);
drop(tx_2);
assert!(selector.next().await.is_none());
assert!(selector.is_empty());Trait Implementations
Sourceimpl Clone for TryStreamBasic
impl Clone for TryStreamBasic
Sourcefn clone(&self) -> TryStreamBasic
fn clone(&self) -> TryStreamBasic
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TryStreamBasic
Sourceimpl Debug for TryStreamBasic
impl Debug for TryStreamBasic
Sourceimpl Default for TryStreamBasic
impl Default for TryStreamBasic
Sourcefn default() -> TryStreamBasic
fn default() -> TryStreamBasic
Returns the “default value” for a type. Read more