TryStreamReclaim

Struct TryStreamReclaim 

pub struct TryStreamReclaim;
Yield stream’s items annotated with stream Id (stopping after first error), and the exhausted/failed stream itself.

Enables Task implementation on any type that implements TryStream.

The stream will be polled for items until it is exhausted or yields an error. Selector will yield all items and the first error, attaching stream’s task Id to each. After that, the Selector will yield the exhausted/failed stream.

let (tx_1, rx_1) = mpsc::unbounded::<Result<i32, &'static str>>();
let (tx_2, rx_2) = mpsc::unbounded::<Result<i32, &'static str>>();
let mut selector = Selector::<_, TryStreamReclaim>::default();
let id_1 = selector.push(rx_1).id().clone();
let id_2 = selector.push(rx_2).id().clone();
tx_1.unbounded_send(Err("error")).unwrap();
let item: (Removed<_>, Result<_, _>) = selector
    .next()
    .await
    .unwrap()
    .break_value()
    .unwrap();
assert_eq!(item.0.id(), &id_1);
assert_eq!(
    item.1,
    Err("error"),
);
tx_2.unbounded_send(Ok(1)).unwrap();
let item: (Id<_>, i32) = selector
    .next()
    .await
    .unwrap()
    .continue_value()
    .unwrap();
assert_eq!(item.0, id_2);
assert_eq!(item.1, 1);
drop(tx_2);
let item: (Removed<_>, Result<_, _>) = selector
    .next()
    .await
    .unwrap()
    .break_value()
    .unwrap();
assert_eq!(item.0.id(), &id_2);
assert_eq!(item.1, Ok(()));
assert!(selector.is_empty());