pub struct TryStreamWithId;Expand description
Yield stream’s items annotated with stream Id (stopping after first error).
Enables Task implementation on any type that implements TryStream.
The stream will be polled for items until it is exhausted or yields an error.
Selector will yield all items and the first error,
attaching stream’s task Id to each.
After that, the Selector will silently drop the stream.
let (tx_1, rx_1) = mpsc::unbounded::<Result<i32, &'static str>>();
let (tx_2, rx_2) = mpsc::unbounded::<Result<i32, &'static str>>();
let mut selector = Selector::<_, TryStreamWithId>::default();
let id_1 = selector.push(rx_1).id().clone();
let id_2 = selector.push(rx_2).id().clone();
tx_1.unbounded_send(Err("error")).unwrap();
assert_eq!(
selector.next().await.unwrap(),
(id_1, Err("error")),
);
tx_2.unbounded_send(Ok(1)).unwrap();
assert_eq!(
selector.next().await.unwrap(),
(id_2, Ok(1)),
);
drop(tx_2);
assert!(selector.next().await.is_none());
assert!(selector.is_empty());Trait Implementations
Sourceimpl Clone for TryStreamWithId
impl Clone for TryStreamWithId
Sourcefn clone(&self) -> TryStreamWithId
fn clone(&self) -> TryStreamWithId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TryStreamWithId
Sourceimpl Debug for TryStreamWithId
impl Debug for TryStreamWithId
Sourceimpl Default for TryStreamWithId
impl Default for TryStreamWithId
Sourcefn default() -> TryStreamWithId
fn default() -> TryStreamWithId
Returns the “default value” for a type. Read more