Module pollable

Module pollable 

Traits that make the Selector generic over asynchronous tasks and polling logic.

Unless you want to exercise the full flexibility of the selector, you don’t need to use these traits. You can use plain FutureSelector and StreamSelector.

Structs

PollAsFuture
Marker trait that allows for a blanket implementation of PollWith on all Futures.
PollAsStream
Marker trait that allows for a blanket implementation of PollWith on all Streams.

Traits

PollStrategy
Determines the type of pollable task that can be stored in a Selector.
PollWith
Determines how the Selector polls the tasks and interprets their outputs.