Module iter
async_
selector
0.3.2
Module iter
Module Items
Structs
In async_
selector::
selector
async_selector
::
selector
Module
iter
Types for iterating over tasks stored in a
Selector
.
Structs

Extract
If
Iterator which uses a closure to determine if a task should be removed from a
Selector
.
Into
Iter
Iterator that returns tasks stored previously in a
Selector
.
Iter
Iterator that visits tasks stored in a
Selector
.
IterMut
Iterator that allows for modifying tasks stored in a
Selector
.