pub struct Selector<T, P = PollDirect> { /* private fields */ }Expand description
Selector over a dynamic set of pollable tasks, for example Futures and Streams.
Designed for optimal performance when polling a large number of tasks (see example).
Allows for:
- Safely injecting shared state into the tasks (see
Pollable). - Accessing and removing the tasks by unique ids.
Unless you want to exercise the full flexibility of this type,
you can use the specialized FutureSelector
and StreamSelector.
Removal
The selector creates a heap allocation for each stored task. Removing a task from the selector does not instantly free that memory. The memory can only be freed when:
- all
Idinstances for this task are dropped, AND Removedinstance is dropped or consumed, AND- the
Waker(and all its clones) passed when polling the task are dropped or consumed, AND - the selector observes the task removal.
The selector always eventually observes the removal when polled.
Wakeups
The selector uses a smart strategy for polling the tasks. A task is only polled in the following cases:
- after it is pushed into the selector
- after it yields a non-terminal value
- after the waker passed to
PollProxy::poll_progressinsideContextis woken
To avoid nasty surprises, keep this in mind when:
- Modifying a task borrowed from the selector
- Polling the selector with different extension types
See example.
Panic
If the task panics when polled, the task is removed from the selector and dropped. The selector remains valid.
Implementations
Sourceimpl<T, P> Selector<T, P>
impl<T, P> Selector<T, P>
Sourcepub fn push_with_id(&mut self, task: T) -> Id<T>
pub fn push_with_id(&mut self, task: T) -> Id<T>
Pushes a new task into the selector and returns its unique id.
This method is O(1).
Sourcepub fn wake_all(&self)
pub fn wake_all(&self)
Manually wakes all tasks in the selector.
Depending on the PollProxy::poll_progress implementation,
this might be required when polling with different extension types.
See the wakeups section.
This method is O(n).
Sourcepub fn iter(&self) -> Iter<'_, T> ⓘ
pub fn iter(&self) -> Iter<'_, T> ⓘ
Returns an iterator over the tasks in the selector.
The tasks are visited in the insertion order.
Sourcepub fn iter_mut(&mut self) -> IterMut<'_, T> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, T> ⓘ
Returns an iterator that allows modifying each task in the selector.
The tasks are visited in the insertion order.
Important: before modifying tasks stored in the selector, see the wakeups section.
Sourcepub fn extract_if<F>(&mut self, pred: F) -> ExtractIf<'_, T, F> ⓘ
pub fn extract_if<F>(&mut self, pred: F) -> ExtractIf<'_, T, F> ⓘ
Creates an iterator which uses a closure to determine if a task should be removed.
If the closure returns true, the task is removed from the selector and yielded.
If the returned ExtractIf is not exhausted, e.g. because it is dropped without iterating or the iteration short-circuits,
then the remaining tasks will be retained.
Important: before removing tasks from the selector, see the removal section.
Sourcepub fn get(&self, id: &Id<T>) -> Option<Borrowed<'_, T>>
pub fn get(&self, id: &Id<T>) -> Option<Borrowed<'_, T>>
Returns an immutable reference to the task with the given id.
Returns None if the task is not found in this selector,
for example because it was removed or has already finished.
This method is O(1).
Sourcepub fn get_mut(&mut self, id: &Id<T>) -> Option<BorrowedMut<'_, T>>
pub fn get_mut(&mut self, id: &Id<T>) -> Option<BorrowedMut<'_, T>>
Returns a mutable reference to the target with the given id.
Returns None if the task is not found in this selector,
for example because it was removed or has already finished.
This method is O(1).
Important: before modifying tasks stored in the selector, see the wakeups section.
Sourcepub fn remove(&mut self, id: &Id<T>) -> Option<Removed<T>>
pub fn remove(&mut self, id: &Id<T>) -> Option<Removed<T>>
Removes the task with the given id from the selector.
Returns None if the task is not found in the selector,
for example because it was removed or has already finished.
This method is O(1).
Important: before removing tasks from the selector, see the removal section.
Sourcepub fn with_ext<'s, 'e, 'emut, E, EMut>(
&'s mut self,
ext: &'e E,
ext_mut: &'emut mut EMut,
) -> WithExt<'s, 'e, 'emut, T, P, E, EMut>
pub fn with_ext<'s, 'e, 'emut, E, EMut>( &'s mut self, ext: &'e E, ext_mut: &'emut mut EMut, ) -> WithExt<'s, 'e, 'emut, T, P, E, EMut>
Sourcepub fn with_ext_and_id<'s, 'e, 'emut, E, EMut>(
&'s mut self,
ext: &'e E,
ext_mut: &'emut mut EMut,
) -> WithExtAndId<'s, 'e, 'emut, T, P, E, EMut>
pub fn with_ext_and_id<'s, 'e, 'emut, E, EMut>( &'s mut self, ext: &'e E, ext_mut: &'emut mut EMut, ) -> WithExtAndId<'s, 'e, 'emut, T, P, E, EMut>