FutureBasic

Struct FutureBasic 

pub struct FutureBasic;
Yield future’s output.

Enables Task implementation on any type that implements Future.

The future will be polled until it resolves. After that, the Selector will silently drop it and yield the output.

let mut selector = (0..4)
    .map(std::future::ready)
    .collect::<Selector<_, FutureBasic>>();
for i in 0..4 {
    let j: i32 = selector.next().await.unwrap();
    assert_eq!(j, i);
}
assert!(selector.is_empty());