pub struct StreamBasic;Expand description
Yield stream’s items.
Enables Task implementation on any type that implements Stream.
The stream will be polled for items until it is exhausted.
Selector will yield all items.
After that, the Selector will silently drop the stream.
let mut selector = (0..4)
.map(|i| futures::stream::repeat(i).take(2))
.collect::<Selector<_, StreamBasic>>();
for i in 0..8 {
let j: i32 = selector.next().await.unwrap();
assert_eq!(j, i % 4);
}
assert!(selector.next().await.is_none());
assert!(selector.is_empty());Trait Implementations
Sourceimpl Clone for StreamBasic
impl Clone for StreamBasic
Sourcefn clone(&self) -> StreamBasic
fn clone(&self) -> StreamBasic
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for StreamBasic
Sourceimpl Debug for StreamBasic
impl Debug for StreamBasic
Sourceimpl Default for StreamBasic
impl Default for StreamBasic
Sourcefn default() -> StreamBasic
fn default() -> StreamBasic
Returns the “default value” for a type. Read more