StreamWithId

Struct StreamWithId 

pub struct StreamWithId;
Yield stream’s items annotated with stream Id.

Enables Task implementation on any type that implements Stream.

The stream will be polled for items until it is exhausted. Selector will yield all items, attaching stream’s task Id to each. After that, the Selector will silently drop the stream.

let (tx, rx) = mpsc::unbounded::<i32>();
let mut selector = Selector::<_, StreamWithId>::default();
let id = selector.push(rx).id().clone();
tx.unbounded_send(1).unwrap();
let item: (Id<_>, i32) = selector.next().await.unwrap();
assert_eq!(item.0, id);
assert_eq!(item.1, 1);
drop(tx);
assert!(selector.next().await.is_none());
assert!(selector.is_empty());